[PATCH v9] seedrng: import SeedRNG utility for kernel RNG seed files
Bernhard Reutner-Fischer
rep.dot.nop at gmail.com
Fri Apr 29 23:42:40 UTC 2022
On Fri, 29 Apr 2022 18:35:54 +0200
Denys Vlasenko <vda.linux at googlemail.com> wrote:
> Even partial removal of these complicated error paths
> cuts down the size by ~10%
It's one of those situations where all you would really want is spend
100b in the kernel to "credit" seed. Be it via /sys or the first bit of
the write fops does not matter. If that distinction even makes sense.
Distros could then just cat/dd their noise to the pool and be done.
The initial proposal had more than 3k.
The tool sounds like it should fit in about 1k if we're forced to ioctl
and cannot simply use the shell. We'd all be better off to remove that
unnecessary ioctl bloat from the kernel and userspace. It does not make
any sense at all.
In shell it would probably be done in a few hundred bytes, once and for
all.
PS: See
http://lists.busybox.net/pipermail/busybox/2022-April/089590.html
for a -260b against an older incarnation.
More information about the busybox
mailing list